NotificationService class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
initialize(
{String? androidNotificationIcon}) → Future< void> -
isHaveNotificationPermission(
) → Future< bool> -
processLaunchPayload(
) → void -
requestNotificationPermission(
) → Future< void> -
showNotification(
{required int id, required String title, required String body, String? payload}) → Future< void> -
showNotificationForLogger(
LogEntry logEntry) → Future< void>
Constants
- apiLogPayload → const String
- channelDescription → const String
- channelId → const String
- channelName → const String
- groupKey → const String